@@ -38,7 +38,11 @@
  * Super NES and Super Nintendo Entertainment System are trademarks of
  * Nintendo Co., Limited and its subsidiary companies.
  */
+
 #include "snes9x.h"
+
+#ifdef USE_SA1
+
 #include "ppu.h"
 #include "cpuexec.h"
 
@@ -92,10 +96,13 @@ void S9xSA1Reset ()
     SA1.PC = NULL;
     SA1.PCBase = NULL;
     S9xSA1SetPCBase (SA1Registers.PC);
-    //SA1.S9xOpcodes = S9xSA1OpcodesM1X1; // unused
 
+#if !CONF_BUILD_ASM_SA1
+    SA1.S9xOpcodes = S9xSA1OpcodesM1X1;
     S9xSA1UnpackStatus();
-    //S9xSA1FixCycles (); // unused
+    S9xSA1FixCycles ();
+#endif
+
     SA1.Executing = TRUE;
     SA1.BWRAM = Memory.SRAM;
     Memory.FillRAM [0x2225] = 0;
@@ -135,8 +142,10 @@ void S9xFixSA1AfterSnapshotLoad ()
     SA1.ShiftedDB = (uint32) SA1Registers.DB << 16;
 
     S9xSA1SetPCBase (SA1.ShiftedPB + SA1Registers.PC);
+#if !CONF_BUILD_ASM_SA1
     S9xSA1UnpackStatus ();
-    //S9xSA1FixCycles (); // unused
+    S9xSA1FixCycles ();
+#endif
     SA1.VirtualBitmapFormat = (Memory.FillRAM [0x223f] & 0x80) ? 2 : 4;
     Memory.BWRAM = Memory.SRAM + (Memory.FillRAM [0x2224] & 7) * 0x2000;
     S9xSA1SetBWRAMMemMap (Memory.FillRAM [0x2225]);
@@ -900,3 +909,6 @@ void S9xSA1ReadVariableLengthData (bool8 inc, bool8 no_shift)
 	Memory.FillRAM [0x225b] = (uint8) (addr >> 16);
     }
 }
+
+#endif
+
